@@ -10,8 +10,6 @@ from matplotlib import ticker
 import aerosandbox.numpy as np
 from aerosandbox.tools.string_formatting import eng_string
 
-# plt.ion()
-
 ### Define color palettes
 palettes = {
     "categorical": [
@@ -34,6 +32,7 @@ mpl.rcParams["figure.dpi"] = 200
 mpl.rcParams["axes.formatter.useoffset"] = False
 mpl.rcParams["contour.negative_linestyle"] = 'solid'
 
+
 def set_ticks(
         x_major: Union[float, int] = None,
         x_minor: Union[float, int] = None,
@@ -50,9 +49,17 @@ def set_ticks(
     if y_minor is not None:
         ax.yaxis.set_minor_locator(ticker.MultipleLocator(base=y_minor))
 
+
 def equal():
     plt.gca().set_aspect("equal", adjustable='box')
 
+
+def figure3d(*args, **kwargs):
+    fig = plt.figure(*args, **kwargs)
+    ax = plt.axes(projection='3d')
+    return fig, ax
+
+
 def adjust_lightness(color, amount=1.0):
     """
     Converts a color to HLS space, then mulitplies the lightness by `amount`, then converts back to RGB.
@@ -103,8 +110,10 @@ def show_plot(
 
     if pretty_grids:
         for ax in axes:
-            ax.grid(True, 'major', axis='both', linewidth=1.6)
-            ax.grid(True, 'minor', axis='both', linewidth=0.7)
+            if not ax.get_label() == '<colorbar>':
+                if not ax.name == '3d':
+                    ax.grid(True, 'major', axis='both', linewidth=1.6)
+                    ax.grid(True, 'minor', axis='both', linewidth=0.7)
 
     ### Determine if a legend should be shown
     if legend is None:
@@ -136,21 +145,22 @@ def show_plot(
 
 
 def contour(
-        X,
-        Y,
-        Z,
-        levels: Union[int, List, np.ndarray] = None,
-        colorbar=True,
-        linelabels=True,
+        X: np.ndarray,
+        Y: np.ndarray,
+        Z: np.ndarray,
+        levels: Union[int, List, np.ndarray] = 31,
+        colorbar: bool = True,
+        linelabels: bool = True,
         cmap=mpl.cm.get_cmap('viridis'),
         alpha: float = 0.7,
-        extend="both",
+        extend: str = "both",
         linecolor="k",
-        linewidths=0.5,
-        extendrect=True,
+        linewidths: float = 0.5,
+        extendrect: bool = True,
         linelabels_format: Union[str, Callable[[float], str]] = eng_string,
-        linelabels_fontsize=8,
-        colorbar_label=None,
+        linelabels_fontsize: float = 8,
+        colorbar_label: str = None,
+        z_log_scale: bool = False,
         contour_kwargs: Dict = None,
         contourf_kwargs: Dict = None,
         colorbar_kwargs: Dict = None,
@@ -187,7 +197,7 @@ def contour(
         contourf_kwargs: Additional keyword arguments for contourf.
         colorbar_kwargs: Additional keyword arguments for colorbar.
         linelabels_kwargs: Additional keyword arguments for the line labels (ax.clabel).
-        **kwargs: Additional keywords, assumed to be for both contour and contourf.
+        **kwargs: Additional keywords, which are passed to both contour and contourf.
 
     Returns: A tuple of (contour, contourf, colorbar) objects.
 
@@ -211,8 +221,19 @@ def contour(
     shared_kwargs = kwargs
     if levels is not None:
         shared_kwargs["levels"] = levels
-    shared_kwargs["alpha"] = alpha
-    shared_kwargs["extend"] = extend
+    if alpha is not None:
+        shared_kwargs["alpha"] = alpha
+    if extend is not None:
+        shared_kwargs["extend"] = extend
+    if z_log_scale:
+
+        shared_kwargs = {
+            "norm"   : mpl.colors.LogNorm(),
+            "locator": mpl.ticker.LogLocator(
+                subs=np.geomspace(1, 10, 4 + 1)[:-1]
+            ),
+            **shared_kwargs
+        }
 
     if colorbar_label is not None:
         colorbar_kwargs["label"] = colorbar_label
@@ -253,6 +274,10 @@ def contour(
 
     if colorbar:
         cbar = plt.colorbar(**colorbar_kwargs)
+
+        if z_log_scale:
+            cbar.ax.yaxis.set_major_locator(mpl.ticker.LogLocator())
+            cbar.ax.yaxis.set_major_formatter(mpl.ticker.LogFormatter())
     else:
         cbar = None
 
@@ -260,24 +285,3 @@ def contour(
         plt.gca().clabel(cont, **linelabels_kwargs)
 
     return cont, contf, cbar
-
-# def contour(
-#         func: Callable,
-#         x_range: Tuple[Union[float,int],Union[float,int]],
-#         y_range: Tuple[Union[float,int],Union[float,int]],
-#         resolution:int =50,
-#         show:bool=True,  # type: bool
-# ):
-#     """
-#     Makes a contour plot of a function of 2 variables. Can also plot a list of functions.
-#     :param func: function of form f(x,y) to plot.
-#     :param x_range: Range of x values to plot, expressed as a tuple (x_min, x_max)
-#     :param y_range: Range of y values to plot, expressed as a tuple (y_min, y_max)
-#     :param resolution: Resolution in x and y to plot. [int]
-#     :param show: Should we show the plot?
-#     :return:
-#     """
-#     fig, ax = plt.subplots(1, 1, figsize=(6.4, 4.8), dpi=200)
-#     x = np.linspace(x_range[0], x_range[1], resolution)
-#     y = np.linspace(y_range[0], y_range[1], resolution)
-#     # TODO finish function
